@@ -2,7 +2,7 @@
 /// @file  cpu_supports_arm_sve.hpp
 ///        Check if the CPU supports the ARM SVE instruction set.
 ///
-/// Copyright (C) 2024 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2025 Kim Walisch, <kim.walisch@gmail.com>
 ///
 /// This file is distributed under the BSD License. See the COPYING
 /// file in the top level directory.
@@ -11,17 +11,17 @@
 #ifndef CPU_SUPPORTS_ARM_SVE_HPP
 #define CPU_SUPPORTS_ARM_SVE_HPP
 
-#include <macros.hpp>
+namespace primecount {
 
-#if __has_builtin(__builtin_cpu_supports)
+bool has_arm_sve();
+
+} // namespace
 
 namespace {
 
 /// Initialized at startup
-const bool cpu_supports_sve = __builtin_cpu_supports("sve");
+const bool cpu_supports_sve = primecount::has_arm_sve();
 
 } // namespace
 
-#endif // __builtin_cpu_supports
-
 #endif
