@@ -4,7 +4,7 @@
 ///        computation of the 2nd partial sieve function.
 ///        It is used by the P2(x, a) and B(x, y) functions.
 ///
-/// Copyright (C) 2021 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2025 Kim Walisch, <kim.walisch@gmail.com>
 ///
 /// This file is distributed under the BSD License. See the COPYING
 /// file in the top level directory.
@@ -17,6 +17,7 @@
 #include <OmpLock.hpp>
 
 #include <stdint.h>
+#include <string>
 
 namespace primecount {
 
@@ -28,8 +29,7 @@ public:
   int get_threads() const;
 
 private:
-  void print_status();
-
+  std::string get_status();
   int64_t low_ = 0;
   int64_t sieve_limit_ = 0;
   int64_t min_thread_dist_ = 0;
