@@ -14,8 +14,10 @@
 #include <macros.hpp>
 
 #include <stdint.h>
+#include <string>
 
-#if __cplusplus >= 201703L && __has_include(<string_view>)
+#if __cplusplus >= 201703L && \
+    __has_include(<string_view>)
   #include <string_view>
   using string_view_t = std::string_view;
 #else
@@ -24,6 +26,8 @@
 
 namespace primecount {
 
+std::string to_string(double x, int precision);
+
 void set_print(bool print);
 void set_print_variables(bool print_variables);
 
@@ -37,6 +41,7 @@ void print(maxint_t x, int64_t y, int64_t z, int64_t c, int threads);
 void print_vars(maxint_t x, int64_t y, int threads);
 void print_vars(maxint_t x, int64_t y, int64_t c, int threads);
 void print_seconds(double seconds);
+void print_status(const std::string& status);
 
 void print_gourdon(maxint_t x, int64_t y, int64_t z, int64_t k, int threads);
 void print_gourdon_vars(maxint_t x, int64_t y, int threads);
